#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-i7genKSC534tGlcvtyhBS
key:                  gitit-0.15.1.2-i7genKSC534tGlcvtyhBS
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  84fafd131cfaf7ee15f1b1d7ca7a1275
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-i7genKSC534tGlcvtyhBS
depends:
    HStringTemplate-0.8.8-5dHRvKLIRz1BbNvc1fSVCy
    HTTP-4000.4.1-6Ryqaia1ysN8649RPcrbhN
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.1.0-A71cfLUaGyLArzjDm23YCT base-4.18.2.1
    base64-bytestring-1.2.1.0-5MSzfiv89GoDsDZeQHrP12
    blaze-html-0.9.2.0-Gk1nEKAeDWeH1PdieMnmSe bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-19IQEgFM1LJCgi46od8jnv
    feed-1.3.2.1-8ImaGWGZ7dB31ZWSwSH4gg filepath-1.4.300.1
    filestore-0.6.5.1-LZ56UEIMBED3Oh7RDVXtYY ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-5nFKXBAiHMN7giMOY6XO3v
    hoauth2-2.14.0-DJvnh0IpN9oAcKSItvLyVv
    hslogger-1.3.2.0-CM8NsFUCpnoLRKriB2ewjm
    http-client-tls-0.3.6.4-20BoFilNt6wH0DhGvOn6jR
    http-conduit-2.3.9.1-EKKOWRGT4W2JitVBqW7oIK
    json-0.10-LReowwPassf9sg4sWXwqRo mtl-2.3.1
    network-3.1.4.0-FNXzQuurZ9fI5swP2Jnlmv
    network-bsd-2.8.1.0-2qhq45Blo6J1tp8b9L4EZr
    network-uri-2.6.4.2-3MJZvR23bIQBStooaLGnnq
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-H6u8ypHH4zH8pk8eIz1bUw
    pandoc-types-1.23.1-JmTzJDAT6GHt2Q324FBHd parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-HxKRUfG9EsP49tpKKvuFBX
    recaptcha-0.1.0.4-7wH1fRl0xGMMs8G01TVlA
    safe-0.3.21-5cn9jHHG57P2ECGkqRZYEd
    skylighting-0.14.4-29awmYjyDMeCKzDLCM6JuR
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-DZTbXK4CxLdGWbwPFrkwiu
    tagsoup-0.14.8-JeC5uC4ONGH46OYP0s8xkX
    temporary-1.3-BugtgBxw3NR7rQmKFO3qXs text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-XOyx2PdKAr6kIogZjJBxL
    url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    uuid-1.3.16.1-HqvO2ylC8LwJrSxdLHFr3Z xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-Iom0dlLAKBEHu7UUVyZl15
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-v46JSnCLYgB50nz2vHrrm
    zlib-0.7.0.0-4ncCJZLRNBlGGmfQWrrrYG

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

